@@ -98,15 +98,17 @@ class Gnuplot(object):
 
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, log = False, **kwargs):
         '''
-        attributes and kwargs are non-ordered, if there is order requirement,
-        please call set many times in order after init.
+        *args: The flag parameter in gnuplot
+        log: If print the gnuplot log
+        **kwargs: the flag that need to be set. You can also set them in the set() function.
         '''
         self.gnuplot = subprocess.Popen(['gnuplot','-p'], shell=True, stdin=subprocess.PIPE)
         # forward write and flush methods:
         self.write = self.gnuplot.stdin.write
         self.flush = self.gnuplot.stdin.flush
+        self.log = log
 
         for v in args:
             self.cmd('set %s' %(v))
@@ -133,7 +135,8 @@ class Gnuplot(object):
             commands += map(lambda x: x.strip(), cmd)
 
         for c in commands:
-            #print("\033[1;34m[py-gnuplot]\033[0m%s" %(c))
+            if self.log:
+                print("\033[1;34m[py-gnuplot]\033[0m %s" %(c))
             self.__call__('%s' %(c))
 
     def close(self):
